@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.5003';
+our $VERSION = '0.5004';
 
 use Moo;
 use strictures 2;
@@ -703,7 +703,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.5003
+version 0.5004
 
 =head1 SYNOPSIS
 
@@ -965,10 +965,10 @@ given, the closed hihat is used.
 
 Add a steady 3/x beat to the score.
 
-Defaults:
+Defaults for all metronome methods:
 
   bars: The object B<bars>
-  cymbal: B<ride1>
+  cymbal: B<closed_hh>
   tempo: B<quarter-note>
   swing: 50 percent = straight-time
 
@@ -980,14 +980,7 @@ Defaults:
   $d->metronome4($bars, $cymbal, $tempo);
   $d->metronome4($bars, $cymbal, $tempo, $swing);
 
-Add a steady 4/4 swing beat to the score.
-
-Defaults:
-
-  bars: The object B<bars>
-  cymbal: B<ride1>
-  tempo: B<quarter-note>
-  swing: 50 percent = straight-time
+Add a steady 4/x beat to the score.
 
 =head2 metronome5
 
